# Test Coverage Report

Generated: Mon 2013-04-29 09:50 CEST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 219 | 189 | 28 | 99.0%
frequently.__init__ | 1 | 0 | 0 | 0.0%
frequently.forms | 37 | 30 | 7 | 100.0%
frequently.models | 44 | 33 | 10 | 97.1%
frequently.templatetags.frequently_tags | 10 | 8 | 2 | 100.0%
frequently.views | 127 | 118 | 9 | 100.0%

Excluded packages and modules
Error packages and modules